@@ -18,7 +18,10 @@ We ignore SOA records, which Amazon would handle for us.
 Our TXT records handling uses "T" not ":".
 
 =item *
-Our MX record handling allows a name to be set with no IP.
+Our SRV records are non-standard.
+
+=item *
+Our MX record handling allows a name to be set without IP.
 
 =back
 
@@ -100,6 +103,42 @@ sub new
         $self->{ 'value' } = $data[1];
         $self->{ 'ttl' }   = $data[2] || 300;
     }
+    elsif ( $rec eq '_' )
+    {
+
+        # The long-form is:
+        #  $name.$proto.$domain : $hostname : $port : $prior : $weight : $ttl
+        #
+        # The short-form is much more common and useful:
+        #  $name.$proto.$domain : $hostname : $port : $ttl
+        #
+        $self->{ 'type' } = "SRV";
+        $self->{ 'name' } = "_" . $data[0];
+
+        if ( scalar(@data) == 4 )
+        {
+            my $host = $data[1] || 0;
+            my $port = $data[2] || 0;
+            my $ttl  = $data[3] || 300;
+
+            # Bogus priority + weight
+            $self->{ 'value' } = "1 10 $port $host";
+            $self->{ 'ttl' }   = $ttl;
+        }
+        else
+        {
+            my $host     = $data[1] || 0;
+            my $port     = $data[2] || 0;
+            my $priority = $data[3] || 1;
+            my $weight   = $data[4] || 10;
+            my $ttl      = $data[5] || 300;
+
+            # Bogus priority + weight
+            $self->{ 'value' } = "$priority $weight $port $host";
+            $self->{ 'ttl' }   = $ttl;
+        }
+
+    }
     elsif ( $rec eq '6' )
     {
 
